;;; otter-init.el
;;; this file is part of otter-mode
;;; a mode for editing and running otter input files

;; Author: Holger Schauer <Holger.Schauer@gmd.de>

;; This file sets up some initial values
;; it defines the options and parameters as well as
;; the commands otter knows about

(provide 'otter-init)
(load "otter-insert.el")
(load "otter-compile")

;; define some local variables
(defvar otter-program "otter" 
"*This must be set to the absolute path where otter will reside.")
(defvar otter-buffer nil "The name of the buffer in which otter runs.")
(defvar otter-out-extension ".oout" 
"*The extension used to generate output files from Otter.")
(defvar otter-in-extension1 "\\.ot"
"*The standard extension to recognize input-files for Otter. 
Note that the \\ before the period is a must !")
(defvar otter-in-extension2 "\\.in"
"*An other extension to recognize input-files for Otter.
Note that the \\ before the period is a must !")
(defvar otter-input-buffer nil
"*This points to the last used input-file buffer.")


;;; now set up some initial values
(defconst otter-cl-f-list
  '(("usable" 1) ("sos" 2) ("demodulators" 3) ("passive" 4))
  "The list of which lists of clauses and/or formulas maybe build.")

(defconst otter-weight-list
  '(("pick_given" 1) ("purge_gen" 2) ("pick_and_purge" 3) ("terms" 4))
  "The list of the arguments to weight_list(arg).")

(defconst otter-functor-types
  '(("xfx" 1) ("xfy" 2) ("yfx" 3) ("fx" 4) ("fy" 5) ("xf" 6) ("yx" 7))
  "The possible functor types for operator declarations.")

; this is the completion-list for options
(defconst otter-options-list 
 '(; Main Loop Flags
   ("sos_queue" 1) ("sos_stack" 2) ("input_sos_first" 3)
   ("interactive_given" 4) ("print_given" 5) ("print_lists_at_end" 6)
   ; Inference Rules
   ("binary_res" 10) ("hyper_res" 11) ("neg_hyper_res" 12)
   ("ur_res" 13) ("para_into" 14)  ("para_from" 15) 
   ("demod_inf" 16)
   ; Paramodulation Flags
   ("para_from_left" 20) ("para_from_right" 21)
   ("para_into_left" 22) ("para_into_right" 23)
   ("para_from_vars" 24) ("para_into_vars" 25)
   ("para_from_units_only" 26) ("para_skip_skolem" 27)
   ("para_ones_rule" 28) ("para_all" 29)
   ; Flags for Handling Generated Clauses
   ("detailed_history" 30) ("order_history" 31) ("unit_deletion" 32)
   ("delete_identical_nested_skolem" 33) ("sort_literals" 34)
   ("for_sub" 35) ("back_sub" 36) ("factor" 37)
   ; Demodulation and Ordering Flags
   ("demod_history" 40) ("order_eq" 41) 
   ("eq_units_both_ways" 42) ("demod_linear" 43)
   ("demod_out_in" 44) ("dynamic_demod" 45) 
   ("dynamic_demod_all" 46) ("dynamic_demod_lex_dep" 47)
   ("back_demod" 48) ("knuth_bendix" 49) ("lrpo" 50)
   ("lex_order_vars" 51) ("symbol_elim" 52)
   ; Input
   ("check_arity" 60) ("prolog_style_variables" 61)
   ("echo_included_files" 62) ("simplify_fol" 63)
   ("process_input" 64) 
   ; Output
   ("very_verbose" 70) ("print_kept" 71)
   ("print_proofs" 72) ("print_new_demod" 73)
   ("print_back_demod" 74) ("print_back_sub" 75)
   ("display_terms" 76) ("pretty_print" 77) ("bird_print" 78)
   ; Indexing Flags
   ("index_for_back_demod" 80) ("for_sub_fpa" 81)
   ("no_fapl" 82) ("no_fanl" 83)
   ; Miscellanous flags
   ("control_memory" 90) ("order_hyp" 91) ("propositional" 92)
   ("really_delete_clauses" 93) ("atom_wt_max_args" 94)
   ("term_wt_max_args" 95) ("free_all_mem" 96) 
   )
"Contains all options known to Otter.")

(defconst otter-parm-list
  '(("report" 1)
    ; Limits on the search
    ("max_seconds" 10) ("max_gen" 11) ("max_kept" 12)
    ("max_given" 13) ("max_mem" 14)
    ; Limits on Properties of generated clauses
    ("max_literals" 20) ("max_weight" 21) 
    ("max_distinct_vars" 22)
    ; Indexing Parameters
    ("fpa_literals" 30) ("fpa_terms" 31)
    ; Miscellanous
    ("pick_given_ratio" 40) ("interrupt_given" 41)
    ("demod_limit" 42) ("max_proofs" 43) 
    ("min_bit_width" 44) ("neg_weight" 45)
    ("pretty_print_indent" 46) ("stats_level" 47)
    )
  "Contains all parameters known to Otter.")





